@@ -22,16 +22,14 @@ fn prompt_stderr(prompt: &str) -> Result<String, Box<dyn std::error::Error>> {
     let stdin = io::stdin();
     let mut stdin_iter = stdin.lock().lines();
     eprint!("{}", prompt);
-    Ok(stdin_iter.next().unwrap()?)
+    Ok(stdin_iter.next().ok_or("no input")??)
 }
 
 fn get_distro_name() -> Result<String, Box<dyn std::error::Error>> {
     let os_release = fs::read_to_string("/etc/os-release")?;
     let parsed = inish::parse(&os_release)?;
     let general = parsed.get("").ok_or("no general section")?;
-    Ok(maybe_unquote(
-        general.get("PRETTY_NAME").ok_or("no pretty name")?,
-    )?)
+    maybe_unquote(general.get("PRETTY_NAME").ok_or("no pretty name")?)
 }
 
 fn get_issue() -> Result<String, Box<dyn std::error::Error>> {
@@ -46,11 +44,11 @@ fn get_issue() -> Result<String, Box<dyn std::error::Error>> {
             &get_distro_name().unwrap_or_else(|_| "Linux".to_string()),
         )
         .replace("\\l", &format!("tty{}", vtnr))
-        .replace("\\s", &uts.sysname().to_str().unwrap())
-        .replace("\\r", &uts.release().to_str().unwrap())
-        .replace("\\v", &uts.version().to_str().unwrap())
-        .replace("\\n", &uts.nodename().to_str().unwrap())
-        .replace("\\m", &uts.machine().to_str().unwrap())
+        .replace("\\s", uts.sysname().to_str().unwrap())
+        .replace("\\r", uts.release().to_str().unwrap())
+        .replace("\\v", uts.version().to_str().unwrap())
+        .replace("\\n", uts.nodename().to_str().unwrap())
+        .replace("\\m", uts.machine().to_str().unwrap())
         .replace("\\\\", "\\"))
 }
 
@@ -62,9 +60,9 @@ enum LoginResult {
 fn login(node: &str, cmd: &mut Option<String>) -> Result<LoginResult, Box<dyn std::error::Error>> {
     let username = loop {
         let username = prompt_stderr(&format!("{} login: ", node))?;
-        if username.starts_with('!') {
-            *cmd = Some(username[1..].to_string());
-            eprintln!("Login command changed to: {}", &username[1..]);
+        if let Some(u) = username.strip_prefix('!') {
+            *cmd = Some(u.to_string());
+            eprintln!("Login command changed to: {u}");
             continue;
         }
         break username;
@@ -148,7 +146,7 @@ fn main() {
     let matches = match opts.parse(&args[1..]) {
         Ok(m) => m,
         Err(f) => {
-            println!("{}", f.to_string());
+            println!("{}", f);
             print_usage(&program, opts);
             std::process::exit(1);
         }
