@@ -22,7 +22,7 @@ use crate::{error::Error, session::worker};
 
 async fn session_worker_main(config: config::Config) -> Result<(), Error> {
     let raw_fd = config.internal.session_worker as RawFd;
-    let mut cur_flags = unsafe { FdFlag::from_bits_unchecked(fcntl(raw_fd, FcntlArg::F_GETFD)?) };
+    let mut cur_flags = FdFlag::from_bits_retain(fcntl(raw_fd, FcntlArg::F_GETFD)?);
     cur_flags.insert(FdFlag::FD_CLOEXEC);
     fcntl(raw_fd, FcntlArg::F_SETFD(cur_flags))?;
     let sock = unsafe { UnixDatagram::from_raw_fd(raw_fd) };
