@@ -76,12 +76,12 @@ async fn client_handler(ctx: &Context, mut s: UnixStream) -> Result<(), Error> {
 
         let resp = match req {
             Request::CreateSession { username } => match ctx.create_session(username).await {
-                Ok(()) => client_get_question(&ctx).await,
+                Ok(()) => client_get_question(ctx).await,
                 res => wrap_result(res),
             },
             Request::PostAuthMessageResponse { response } => {
                 match ctx.post_response(response).await {
-                    Ok(()) => client_get_question(&ctx).await,
+                    Ok(()) => client_get_question(ctx).await,
                     res => wrap_result(res),
                 }
             }
@@ -174,15 +174,14 @@ fn get_tty(config: &Config) -> Result<TerminalMode, Error> {
 struct Listener(UnixListener);
 
 impl Listener {
-    fn create(uid: Uid, gid: Gid) -> Result<Listener, Error> {
+    fn create(uid: Uid, gid: Gid) -> Result<(String, Listener), Error> {
         let path = format!("/run/greetd-{}.sock", getpid().as_raw());
         let _ = std::fs::remove_file(&path);
         let listener =
             UnixListener::bind(&path).map_err(|e| format!("unable to open listener: {}", e))?;
         chown(path.as_str(), Some(uid), Some(gid))
             .map_err(|e| format!("unable to chown greetd socket at {}: {}", path, e))?;
-        std::env::set_var("GREETD_SOCK", path);
-        Ok(Listener(listener))
+        Ok((path, Listener(listener)))
     }
 }
 
@@ -199,30 +198,38 @@ impl Drop for Listener {
 }
 
 pub async fn main(config: Config) -> Result<(), Error> {
-    let service = if Path::new("/etc/pam.d/greetd").exists() {
-        "greetd"
-    } else if Path::new("/etc/pam.d/login").exists() {
-        eprintln!("warning: PAM 'greetd' service missing, falling back to 'login'");
-        "login"
+    let service = if Path::new(&format!("/etc/pam.d/{}", config.file.general.service)).exists() {
+        &config.file.general.service
+    } else if Path::new(&format!("/usr/lib/pam.d/{}", config.file.general.service)).exists() {
+        &config.file.general.service
     } else {
-        return Err("PAM 'greetd' service missing".into());
+        return Err(format!("PAM '{}' service missing", config.file.general.service).into());
     };
 
-    let greeter_service = if Path::new("/etc/pam.d/greetd-greeter").exists() {
-        "greetd-greeter"
+    let greeter_service = if Path::new(&format!(
+        "/etc/pam.d/{}",
+        config.file.default_session.service
+    ))
+    .exists()
+    {
+        &config.file.default_session.service
+    } else if Path::new(&format!(
+        "/usr/lib/pam.d/{}",
+        config.file.default_session.service
+    ))
+    .exists()
+    {
+        &config.file.default_session.service
     } else {
         service
     };
 
-    let u = users::get_user_by_name(&config.file.default_session.user).ok_or(format!(
+    let u = nix::unistd::User::from_name(&config.file.default_session.user)?.ok_or(format!(
         "configured default session user '{}' not found",
         &config.file.default_session.user
     ))?;
 
-    let uid = Uid::from_raw(u.uid());
-    let gid = Gid::from_raw(u.primary_group_id());
-
-    let listener = Listener::create(uid, gid)?;
+    let (listener_path, listener) = Listener::create(u.uid, u.gid)?;
 
     let term_mode = get_tty(&config)?;
 
@@ -238,6 +245,7 @@ pub async fn main(config: Config) -> Result<(), Error> {
         term_mode.clone(),
         config.file.general.source_profile,
         config.file.general.runfile,
+        listener_path,
     ));
 
     if let (Some(s), true) = (config.file.initial_session, ctx.is_first_run()) {
